@@ -2,20 +2,20 @@
 from .parse import parse
 
 # NOT, EQ, NEQ, IMPLY, NIMPLY (FIXED)
-from .not import not
+from .not_ import not_
 from .eq import eq
 from .neq import neq
 from .imply import imply
 from .nimply import nimply
 
-# AND, OR, XOR, NAND, NOR, XNOR (VARIABLE)
-from .and import and
-from .or import or
+# # AND, OR, XOR, NAND, NOR, XNOR (VARIABLE)
+from .and_ import and_
+from .or_ import or_
 from .xor import xor
 from .nand import nand
 from .nor import nor
 from .xnor import xnor
 
-# COUNT, SELECT (VARIABLE)
+# # COUNT, SELECT (VARIABLE)
 from .count import count
 from .select import select
